# Copyright (c) 2017, Michael Boyle
# See LICENSE file for details: <https://github.com/moble/quaternion/blob/master/LICENSE>

from __future__ import division, print_function, absolute_import

## Allow the code to function without numba, but discourage it
## strongly.
try:
    from numbapro import njit, jit, vectorize, int64, float64, complex128
    from numba.utils import IS_PY3

    GOT_NUMBA = True
except ImportError:
    try:
        from numba import njit, jit, vectorize, int64, float64, complex128
        from numba.utils import IS_PY3

        GOT_NUMBA = True
    except ImportError:
        import warnings
        import sys

        warning_text = \
            "\n\n" + "!" * 53 + "\n" + \
            "Could not import from either numbapro or numba.\n" + \
            "This means that the code will run MUCH more slowly.\n" + \
            "You probably REALLY want to install numba / numbapro." + \
            "\n" + "!" * 53 + "\n"
        warnings.warn(warning_text)

        def _identity_decorator_outer(*args, **kwargs):
            def _identity_decorator_inner(fn):
                return fn

            return _identity_decorator_inner

        njit = _identity_decorator_outer
        jit = _identity_decorator_outer
        vectorize = _identity_decorator_outer
        int64 = int
        float64 = float
        complex128 = complex
        IS_PY3 = (sys.version_info[:2] >= (3, 0))
        GOT_NUMBA = False

if IS_PY3:
    xrange = range
else:
    xrange = xrange



#!/usr/bin/env python

# Copyright (c) 2017, Michael Boyle
# See LICENSE file for details: <https://github.com/moble/quaternion/blob/master/LICENSE>

from auto_version import calculate_version, build_py_copy_version

def configuration(parent_package='', top_path=None):
    import numpy
    from distutils.errors import DistutilsError
    if numpy.__dict__.get('quaternion') is not None:
        raise DistutilsError('The target NumPy already has a quaternion type')
    from numpy.distutils.misc_util import Configuration
    compile_args = ['-O3']
    config = Configuration('quaternion', parent_package, top_path)
    config.add_extension('numpy_quaternion',
                         ['quaternion.c', 'numpy_quaternion.c'],
                         depends=['quaternion.c', 'quaternion.h', 'numpy_quaternion.c'],
                         extra_compile_args=compile_args, )
    return config


if __name__ == "__main__":
    from os import getenv
    from numpy.distutils.core import setup

    validate = True
    error_on_invalid = False
    if getenv('CI') is not None:
        if getenv('CI').lower() == 'true':
            error_on_invalid = True

    setup(name='numpy-',
          configuration=configuration,
          version=calculate_version(validate, error_on_invalid),
          cmdclass={'build_py': build_py_copy_version},
          url='https://github.com/moble/quaternion',
          author='Michael Boyle',
          author_email='',
    )
